const path = require('path');
const webpack = require('webpack');
const WebpackHelper = require("@studyportals/webpack-helper");
const DllManifestGenerator = require("@studyportals/bob-manifest-generator").DllManifestGenerator;


module.exports = (env, details) => {
	const configuration = WebpackHelper.create({
		entry: {
			monthpicker_v3: [
				'@studyportals/monthpicker/dist/monthpicker.js',
				'@studyportals/monthpicker/dist/monthpicker.css',
			]
		},
		preset: 'typescript',
		output: {
			hash: false,
			fileName: `[name]${details.mode === 'production' ? '.min' : ''}`
		},
		common: {
			output: {
				library: '[name]'
			},
			plugins: [
				new webpack.DllPlugin({
					path: path.resolve(__dirname, `./dist/monthpicker${details.mode === 'production' ? '.min' : ''}.json`),
					name: "[name]",
					entryOnly: true
				}),
				new webpack.DllReferencePlugin({
					manifest: require(
						`@studyportals/vue-config/dist/vue3_library_v5.json`
					)
				}),
			],
			resolve: {
				extensions: ['*', '.ts', '.js', '.json']
			},
			module: {
				rules: [
					{
						test: /\.js|css$/,
						enforce: "pre",
						use: ["source-map-loader"],
					},
				],
			},
		},
		production: {
			plugins: [
				new DllManifestGenerator()
			],
			optimization: {
				moduleIds: 'named'
			}
		}
	});
	
	return configuration.get(details.mode);
}

